import pygame
import random
import math
import time  # Přidáno pro měření času

# Inicializace Pygame
pygame.init()

# Nastavení obrazovky
WIDTH, HEIGHT = 800, 600
screen = pygame.display.set_mode((WIDTH, HEIGHT))
pygame.display.set_caption("Ninja vs Zombies")

# Načtení obrázků
background_img = pygame.image.load("pozadi.png")
ninja_img = pygame.image.load("ninja.png")
zombie_img = pygame.image.load("zombie.png")
shuriken_img = pygame.image.load("shuriken.png")
heart_img = pygame.image.load("heart.png")
game_over_img = pygame.image.load("game_over.png")
play_again_img = pygame.image.load("play_again.png")
ultimate_img = pygame.image.load("ultimate.png")  # Přidán obrázek "ultimate"

# Přizpůsobení velikostí
ninja_img = pygame.transform.scale(ninja_img, (50, 50))
zombie_img = pygame.transform.scale(zombie_img, (50, 50))
shuriken_img = pygame.transform.scale(shuriken_img, (20, 20))
heart_img = pygame.transform.scale(heart_img, (40, 40))
background_img = pygame.transform.scale(background_img, (WIDTH, HEIGHT))
game_over_img = pygame.transform.scale(game_over_img, (400, 200))
play_again_img = pygame.transform.scale(play_again_img, (200, 80))
ultimate_img = pygame.transform.scale(ultimate_img, (100, 100))  # Nastavení velikosti ultimate obrázku

# Herní proměnné
def reset_game():
    global ninja_x, ninja_y, shurikens, zombies, lives, score, running, start_time
    ninja_x, ninja_y = WIDTH // 2, HEIGHT // 2
    shurikens = []
    zombies = []
    lives = 3
    score = 0
    running = True
    start_time = time.time()  # Začátek měření času

reset_game()

# Hlavní smyčka hry
while True:
    while running:
        pygame.time.delay(30)
        screen.blit(background_img, (0, 0))
        screen.blit(ultimate_img, (WIDTH - 120, HEIGHT - 120))  # Zobrazení ultimate obrázku
        
        # Zpracování událostí
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                exit()
            if event.type == pygame.MOUSEBUTTONDOWN:
                mx, my = pygame.mouse.get_pos()
                angle = math.atan2(my - ninja_y, mx - ninja_x)
                speed_x = math.cos(angle) * 10
                speed_y = math.sin(angle) * 10
                shurikens.append([ninja_x + 25, ninja_y + 15, speed_x, speed_y])
        
        # Pohyb hráče
        keys = pygame.key.get_pressed()
        if keys[pygame.K_a] and ninja_x > 0:
            ninja_x -= 5
        if keys[pygame.K_d] and ninja_x < WIDTH - 50:
            ninja_x += 5
        if keys[pygame.K_w] and ninja_y > 0:
            ninja_y -= 5
        if keys[pygame.K_s] and ninja_y < HEIGHT - 50:
            ninja_y += 5
        
        # Pohyb shurikenů
        for s in shurikens:
            s[0] += s[2]
            s[1] += s[3]
        shurikens = [s for s in shurikens if 0 < s[0] < WIDTH and 0 < s[1] < HEIGHT]
        
        # Spawn zombíků
        if random.randint(1, 50) == 1:
            zombies.append([random.randint(0, WIDTH - 50), random.randint(0, HEIGHT - 50)])
        
        # Pohyb zombíků směrem k ninjovi
        for z in zombies:
            angle = math.atan2(ninja_y - z[1], ninja_x - z[0])
            z[0] += math.cos(angle) * 2
            z[1] += math.sin(angle) * 2
        
        # Kolize shurikenů se zombíky
        for s in shurikens:
            for z in zombies:
                if z[0] < s[0] < z[0] + 50 and z[1] < s[1] < z[1] + 50:
                    zombies.remove(z)
                    shurikens.remove(s)
                    score += 1
                    break
        
        # Kolize zombíků s ninjou
        for z in zombies:
            if z[0] < ninja_x + 50 and z[0] + 50 > ninja_x and z[1] < ninja_y + 50 and z[1] + 50 > ninja_y:
                zombies.remove(z)
                lives -= 1
                if lives == 0:
                    running = False
        
        # Vykreslení postav
        screen.blit(ninja_img, (ninja_x, ninja_y))
        for s in shurikens:
            screen.blit(shuriken_img, (s[0], s[1]))
        for z in zombies:
            screen.blit(zombie_img, (z[0], z[1]))
        
        # Zobrazení skóre
        font = pygame.font.SysFont("Arial", 24)
        score_text = font.render(f"Score: {score}", True, (0, 0, 0))
        screen.blit(score_text, (10, 10))
        
        # Zobrazení životů v pravém horním rohu
        for i in range(lives):
            screen.blit(heart_img, (WIDTH - (i + 1) * 50, 10))
        
        pygame.display.update()
    
    # Konec hry - výpočet uplynulého času
    total_time = round(time.time() - start_time, 2)
    
    # Game over obrazovka
    screen.blit(game_over_img, (WIDTH // 2 - game_over_img.get_width() // 2, HEIGHT // 3))
    play_again_rect = screen.blit(play_again_img, (WIDTH // 2 - play_again_img.get_width() // 2, HEIGHT // 3 + game_over_img.get_height() + 20))
    
    # Zobrazení skóre a času hry
    final_text = font.render(f"Score: {score} | Time: {total_time}s", True, (0, 0, 0))
    screen.blit(final_text, (WIDTH // 200 - 100, HEIGHT // 200 + 50))
    
    pygame.display.update()
    
    # Čekání na restart
    waiting = True
    while waiting:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                pygame.quit()
                exit()
            if event.type == pygame.MOUSEBUTTONDOWN:
                if play_again_rect.collidepoint(event.pos):
                    reset_game()
                    waiting = False